@@ -61,7 +61,9 @@ keywords.
 
 import os
 import re
+import json
 import numpy as np
+import warnings
 from contextlib import contextmanager
 
 ROOT = os.path.abspath(os.path.dirname(__file__))
@@ -104,7 +106,7 @@ def check_string(s):
 
 
 def check_vector(s, len=None):
-    """Check that input is vector with required length."""
+    """Check that input is vector of required length."""
     try:
         s = np.array(s)
         assert s.ndim == 1
@@ -126,7 +128,7 @@ def check_version_string(s):
         return s
     else:
         raise ValueError(f'Not supported version format "{s}".'
-                         'Looking for "x.x".')
+                         'Must be of the form "x.x" with x an integer.')
 
 
 DEFAULTS = {
@@ -136,7 +138,7 @@ DEFAULTS = {
                       lambda x: check_vector(x, len=3)],
     'params.ellipsoid': [np.array([6378.137, 6356.752]),
                          lambda x: check_vector(x, len=2)],
-    'params.version': ['7.3', check_version_string],
+    'params.version': ['7.8', check_version_string],
     'params.cdf_to_mjd': [730485, check_int],
 
     # location of coefficient files
@@ -203,26 +205,20 @@ class BasicConfig(dict):
         Parameters
         ----------
         filepath : str
-            Filepath and name to configuration textfile.
+            Filepath and name to json-formatted configuration txt-file.
 
         """
 
         with open(filepath, 'r') as f:
-            for line in f.readlines():
-                # skip comment and empty lines
-                if not line.strip():
-                    continue
-                elif line.strip()[0] == '#':
-                    continue
+            kwargs = json.load(f)
 
-                key, value = line.split(':')
-                value = value.split('#')[0].strip()  # remove comments and \n
+        if len(kwargs) == 0:
+            warnings.warn(
+                'Configuration dictionary loaded from file is empty.')
 
-                # check list input and convert to array
-                if value.startswith('[') and value.endswidth(']'):
-                    value = np.fromstring(value[1:-1], sep=' ')
-
-                self.__setitem__(key.strip(), value)
+        for key, value in kwargs.items():
+            # check format and set key value pairs
+            self.__setitem__(key, value)
 
     def save(self, filepath):
         """
@@ -236,10 +232,13 @@ class BasicConfig(dict):
 
         """
 
+        def default(obj):
+            if isinstance(obj, np.ndarray):
+                return obj.tolist()
+
         with open(filepath, 'w') as f:
-            for key, value in self.items():
-                f.write(f'{key} : {value}\n')
-        f.close()
+            json.dump(self, f, default=default, indent=4, sort_keys=True)
+
         print(f'Saved configuration textfile to {filepath}.')
 
     @contextmanager
