@@ -134,7 +134,7 @@ def load_RC_datfile(filepath=None, parse_dates=None):
         print(f'Accessing {page.url}.')
 
         tree = html.fromstring(page.content)
-        file = tree.xpath('//tr[5]//td[2]//a/text()')[0]  # get name from list
+        file = tree.xpath('//tr[5]//td[2]//a/@href')[0]  # get name from list
         date = tree.xpath('//tr[5]//td[3]/text()')[0]
 
         print(f'Downloading RC-index file "{file}" '
@@ -251,7 +251,7 @@ def load_shcfile(filepath, leap_year=None):
             read_line = np.fromstring(line, sep=' ')
             if read_line.size == 5:
                 name = os.path.split(filepath)[1]  # file name string
-                values = [name] + read_line.astype(np.int).tolist()
+                values = [name] + read_line.astype(int).tolist()
 
             else:
                 data = np.append(data, read_line)
@@ -297,11 +297,11 @@ def save_shcfile(time, coeffs, order=None, filepath=None, nmin=None, nmax=None,
         Take leap years for decimal year conversion into account
         (defaults to ``True``).
     header : str, optional
-        Optional header at beginning of file. Defaults to empty string.
+        Optional header at beginning of file. Defaults to an empty string.
 
     """
 
-    time = np.array(time, dtype=np.float)
+    time = np.asarray(time, dtype=float)
 
     order = 1 if order is None else int(order)
 
@@ -315,19 +315,20 @@ def save_shcfile(time, coeffs, order=None, filepath=None, nmin=None, nmax=None,
     assert (nmin <= nmax), \
         '``nmin`` must be smaller than or equal to ``nmax``.'
 
-    if filepath is None:
-        filepath = 'model.shc'
+    filepath = 'model.shc' if filepath is None else filepath
 
     header = '' if header is None else header
 
+    leap_year = True if leap_year is None else bool(leap_year)
+
     if coeffs.ndim == 1:
         coeffs = coeffs.reshape((1, -1))
 
     coeffs = coeffs[:, (nmin**2-1):((nmax+1)**2-1)]
 
     # compute all possible degree and orders
-    deg = np.array([], dtype=np.int)
-    ord = np.array([], dtype=np.int)
+    deg = np.array([], dtype=int)
+    ord = np.array([], dtype=int)
     for n in range(nmin, nmax+1):
         deg = np.append(deg, np.repeat(n, 2*n+1))
         ord = np.append(ord, [0])
@@ -344,11 +345,9 @@ def save_shcfile(time, coeffs, order=None, filepath=None, nmin=None, nmax=None,
         # write comment line
         f.write(comment)
 
-        # write header lines to 8 significants
         f.write('  ')  # to represent two missing values
         for t in time:
-            f.write(' {:9.4f}'.format(
-                mjd_to_dyear(t, leap_year=leap_year)))
+            f.write(' {:16.8f}'.format(mjd_to_dyear(t, leap_year=leap_year)))
         f.write('\n')
 
         # write coefficient table to 8 significants
@@ -357,7 +356,7 @@ def save_shcfile(time, coeffs, order=None, filepath=None, nmin=None, nmax=None,
             f.write('{:} {:}'.format(n, m))
 
             for value in coeffs[:, row]:
-                f.write(' {:.8e}'.format(value))
+                f.write(' {:16.8f}'.format(value))
 
             f.write('\n')
 
@@ -401,13 +400,13 @@ datetime.datetime(2002, 3, 4)])
     >>> mjd2000(a)
         array([  0., 793.])
 
-    >>> mjd2000(2003, 5, 3, 13, 52, 15)  # May 3rd, 2003, 13:52:15 (hh:mm:ss)
+    >>> mjd2000(2003, 5, 3, 13, 52, 15)  # May 3, 2003, 13:52:15 (hh:mm:ss)
         1218.5779513888888
 
-    >>> mjd2000(np.arange(2000, 2005))  # 1st of January
+    >>> mjd2000(np.arange(2000, 2005))  # January 1 in each year
         array([   0.,  366.,  731., 1096., 1461.])
 
-    >>> mjd2000(np.arange(2000, 2005), 2, 1)  # 1st of February
+    >>> mjd2000(np.arange(2000, 2005), 2, 1)  # February 1 in each year
         array([  31.,  397.,  762., 1127., 1492.])
 
     >>> mjd2000(np.arange(2000, 2005), 2, np.arange(1, 6))
@@ -533,7 +532,7 @@ def dyear_to_mjd(time, leap_year=None):
     leap_year = True if leap_year is None else leap_year
 
     if leap_year:
-        year = np.asarray(time, dtype=np.int)
+        year = np.asarray(time, dtype=int)
         frac_of_year = np.remainder(time, 1.)
 
         isleap = is_leap_year(year)
@@ -587,10 +586,10 @@ def mjd_to_dyear(time, leap_year=None):
     leap_year = True if leap_year is None else leap_year
 
     if leap_year:
-        date = (np.asarray(time, dtype=np.int)*np.timedelta64(1, 'D')
+        date = (np.asarray(time, dtype=int)*np.timedelta64(1, 'D')
                 + np.datetime64('2000-01-01'))  # only precise to date
 
-        year = date.astype('datetime64[Y]').astype(np.int) + 1970
+        year = date.astype('datetime64[Y]').astype(int) + 1970
         days = np.asarray(time) - mjd2000(year, 1, 1)  # days of that year
 
         isleap = is_leap_year(year)
